# content-io

[![Build Status](https://travis-ci.org/5monkeys/content-io.png?branch=master)](https://travis-ci.org/5monkeys/content-io)
[![Coverage Status](https://coveralls.io/repos/5monkeys/content-io/badge.png?branch=master)](https://coveralls.io/r/5monkeys/content-io?branch=master)
[![Downloads](https://pypip.in/v/content-io/badge.png)](https://pypi.python.org/pypi/content-io/)
